@@ -61,7 +61,7 @@ use std::{
 
 use anyhow::{Context, Result};
 
-use chrono::{DateTime, offset::Utc};
+use chrono::{DateTime, NaiveTime, offset::Utc};
 use structopt::{StructOpt, clap::AppSettings};
 
 use crate::{
@@ -182,8 +182,8 @@ enum Operation {
         #[structopt(long, number_of_values = 1)]
         with_password: Vec<String>,
         /// Write verification result here.
-        #[structopt(long)]
-        verify_out: Option<String>,
+        #[structopt(long, alias("verify-out"))]
+        verifications_out: Option<String>,
         /// Certs for verification.
         #[structopt(long, number_of_values = 1)]
         verify_with: Vec<String>,
@@ -285,9 +285,18 @@ pub fn main(sop: &dyn crate::SOP) -> ! {
         Ok(()) => exit(0),
         Err(e) => {
             print_error_chain(&e);
-            if let Ok(e) = e.downcast::<Error>() {
-                exit(e.into())
-            }
+            let e = match e.downcast::<crate::Error>() {
+                Ok(e) => exit(Error::from(e).into()),
+                Err(e) => e,
+            };
+            let e = match e.downcast::<Error>() {
+                Ok(e) => exit(e.into()),
+                Err(e) => e,
+            };
+
+            // XXX: Would be nice to at least inform developers that
+            // we return a generic error here.
+            let _ = e;
             exit(1);
         },
     }
@@ -318,7 +327,12 @@ fn real_main(sop: &dyn crate::SOP) -> Result<()> {
                     println!("{} {}", v.name, v.version);
                 },
                 (false, true) => {
-                    for v in version.extended()? {
+                    let mut versions = version.extended()?;
+                    versions.insert(1, crate::VersionInfo {
+                        name: "sop-rs".into(),
+                        version: env!("CARGO_PKG_VERSION").into(),
+                    });
+                    for v in versions {
                         println!("{} {}", v.name, v.version);
                     }
                 },
@@ -424,7 +438,7 @@ fn real_main(sop: &dyn crate::SOP) -> Result<()> {
             session_key_out,
             with_session_key,
             with_password,
-            verify_out,
+            verifications_out,
             verify_with,
             verify_not_before,
             verify_not_after,
@@ -438,14 +452,14 @@ fn real_main(sop: &dyn crate::SOP) -> Result<()> {
                     None
                 };
 
-            if verify_out.is_none() != verify_with.is_empty() {
+            if verifications_out.is_none() != verify_with.is_empty() {
                 return Err(anyhow::Error::from(Error::IncompleteVerification))
-                    .context("--verify-out and --verify-with \
+                    .context("--verifications-out and --verify-with \
                               must both be given");
             }
 
             let mut verify_out: Box<dyn io::Write> =
-                if let Some(f) = verify_out {
+                if let Some(f) = verifications_out {
                     Box::new(create_file(f)?)
                 } else {
                     Box::new(io::sink())
@@ -673,6 +687,22 @@ fn create_file<S: AsRef<str>>(file: S) -> Result<std::fs::File> {
                 .context(format!("File {:?} exists", f));
         }
 
+        #[cfg(unix)]
+        {
+            if f.starts_with("@FD:")
+                && f[4..].chars().all(|c| c.is_ascii_digit())
+            {
+                use std::os::unix::io::{RawFd, FromRawFd};
+
+                let fd: RawFd = f[4..].parse()
+                    .map_err(|_| Error::UnsupportedSpecialPrefix)?;
+                let f = unsafe {
+                    std::fs::File::from_raw_fd(fd)
+                };
+                return Ok(f);
+            }
+        }
+
         return Err(anyhow::Error::from(Error::UnsupportedSpecialPrefix));
     }
 
@@ -697,7 +727,7 @@ fn parse_bound_round_down(s: &str) -> Result<DateTime<Utc>> {
         // XXX: parse "-" to None once we figure out how to do that
         // with structopt.
         "now" => Ok(Utc::now()),
-        _ => parse_iso8601(s, chrono::NaiveTime::from_hms(0, 0, 0)),
+        _ => parse_iso8601(s, NaiveTime::from_hms_opt(0, 0, 0).unwrap()),
     }
 }
 
@@ -707,7 +737,7 @@ fn parse_bound_round_up(s: &str) -> Result<DateTime<Utc>> {
         // XXX: parse "-" to None once we figure out how to do that
         // with structopt.
         "now" => Ok(Utc::now()),
-        _ => parse_iso8601(s, chrono::NaiveTime::from_hms(23, 59, 59)),
+        _ => parse_iso8601(s, NaiveTime::from_hms_opt(23, 59, 59).unwrap()),
     }
 }
 
