@@ -469,16 +469,31 @@ impl Password {
     ///
     /// [Generating Material with Human-Readable Passwords]: https://www.ietf.org/archive/id/draft-dkg-openpgp-stateless-cli-04.html#name-generating-material-with-hu
     pub fn new(password: Vec<u8>) -> Result<Password> {
-        let s = String::from_utf8(password)
-            .map_err(|_| Error::PasswordNotHumanReadable)?;
+        // Securely erase the password.
+        fn securely_erase(mut p: Vec<u8>) {
+            unsafe {
+                memsec::memzero(p.as_mut_ptr(), p.len());
+            }
+        }
+
+        let mut s = String::from_utf8(password)
+            .map_err(|e| {
+                securely_erase(e.into_bytes());
+                Error::PasswordNotHumanReadable
+            })?;
 
         // Check for leading whitespace.
         if s.trim_start().len() != s.len() {
+            securely_erase(s.into_bytes());
             return Err(Error::PasswordNotHumanReadable);
         }
 
+        // Trim trailing whitespace.
+        s.truncate(s.trim_end().len());
+
         // Check for odd whitespace.
         if s.chars().any(|c| c.is_whitespace() && c != ' ') {
+            securely_erase(s.into_bytes());
             return Err(Error::PasswordNotHumanReadable);
         }
 
